# Changelog

## [0.1.1a2](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.1.1a2) (2024-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.1.0...0.1.1a2)

**Merged pull requests:**

- chore:semver\_versioning [\#38](https://github.com/OpenVoiceOS/ovos-PHAL/pull/38) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
